@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2001, 2002 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #include "imap4d.h"
 
@@ -23,6 +23,9 @@ imap4d_login (struct imap4d_command *command, char *arg)
   char *sp = NULL, *username, *pass;
   int rc;
 
+  if (login_disabled)
+    return util_finish (command, RESP_NO, "Command disabled");
+  
   username = util_getword (arg, &sp);
   pass = util_getword (NULL, &sp);
 
@@ -39,7 +42,7 @@ imap4d_login (struct imap4d_command *command, char *arg)
 
   if (auth_data == NULL)
     {
-      syslog (LOG_INFO, "User '%s': nonexistent", arg);
+      syslog (LOG_INFO, _("User '%s': nonexistent"), arg);
       return util_finish (command, RESP_NO, "User name or passwd rejected");
     }
 
@@ -47,7 +50,7 @@ imap4d_login (struct imap4d_command *command, char *arg)
   openlog ("gnu-imap4d", LOG_PID, log_facility);
   if (rc)
     {
-      syslog (LOG_INFO, "Login failed: %s", arg);
+      syslog (LOG_INFO, _("Login failed: %s"), arg);
       return util_finish (command, RESP_NO, "User name or passwd rejected");
     }
   
@@ -57,7 +60,7 @@ imap4d_login (struct imap4d_command *command, char *arg)
   homedir = mu_normalize_path (strdup (auth_data->dir), "/");
   chdir (homedir);
   namespace_init (homedir);
-  syslog (LOG_INFO, "User '%s' logged in", username);
+  syslog (LOG_INFO, _("User '%s' logged in"), username);
   return util_finish (command, RESP_OK, "Completed");
 }
 
