@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
+/* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Lesser General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   You should have received a copy of the GNU Lesser General Public
+   License along with this library; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #ifndef _MAILUTILS_ARGP_H
 #define _MAILUTILS_ARGP_H
@@ -44,6 +44,10 @@ extern int log_facility;
 extern int mu_argp_error_code;
 extern char *mu_license_text;
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 extern void mu_create_argcv __P ((const char *capa[],
 				  int argc, char **argv,
 				  int *p_argc, char ***p_argv));
@@ -57,5 +61,9 @@ extern int mu_register_capa __P((const char *name, struct argp_child *child));
 extern void mu_print_options __P((void));
 extern const char *mu_check_option __P((char *name));
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
 
