@@ -1,7 +1,6 @@
 
 /*  A Bison parser, made from /home/gray/mailutils/libsieve/./sieve.y
- by  GNU Bison version 1.27
-  */
+    by GNU Bison version 1.28  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
@@ -20,22 +19,22 @@
 
 #line 1 "sieve.y"
 
-/* GNU mailutils - a suite of utilities for electronic mail
+/* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Lesser General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Lesser General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   You should have received a copy of the GNU Lesser General Public
+   License along with this library; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -47,7 +46,7 @@
 
 sieve_machine_t sieve_machine;
 int sieve_error_count;
- 
+
 static void branch_fixup __P((size_t start, size_t end));
  
 
@@ -238,7 +237,7 @@ static const short sieve_yycheck[] = {     0,
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
 #line 3 "/usr/share/bison.simple"
-/* This file comes from bison-1.27.  */
+/* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -451,7 +450,7 @@ __sieve_yy_memcpy (char *to, char *from, unsigned int count)
 #endif
 #endif
 
-#line 216 "/usr/share/bison.simple"
+#line 217 "/usr/share/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into sieve_yyparse.  The argument should have type void *.
@@ -949,11 +948,11 @@ case 26:
 
 		 if (!reg)
 		   sieve_compile_error (sieve_filename, sieve_line_num,
-                                "unknown test: %s",
+                                _("unknown test: %s"),
 				sieve_yyvsp[0].command.ident);
 		 else if (!reg->required)
 		   sieve_compile_error (sieve_filename, sieve_line_num,
-                                "test `%s' has not been required",
+                                _("test `%s' has not been required"),
 				sieve_yyvsp[0].command.ident);
 		 else if (sieve_code_test (reg, sieve_yyvsp[0].command.args))
 		   YYERROR;
@@ -975,11 +974,11 @@ case 28:
 		 sieve_yyval.pc = sieve_machine->pc;
 		 if (!reg)
 		   sieve_compile_error (sieve_filename, sieve_line_num,
-                                "unknown action: %s",
+                                _("unknown action: %s"),
 				sieve_yyvsp[0].command.ident);
 		 else if (!reg->required)
 		   sieve_compile_error (sieve_filename, sieve_line_num,
-                                "action `%s' has not been required",
+                                _("action `%s' has not been required"),
 				sieve_yyvsp[0].command.ident);
 		 else if (sieve_code_action (reg, sieve_yyvsp[0].command.args))
 		   YYERROR;
@@ -1064,7 +1063,7 @@ case 42:
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 542 "/usr/share/bison.simple"
+#line 543 "/usr/share/bison.simple"
 
   sieve_yyvsp -= sieve_yylen;
   sieve_yyssp -= sieve_yylen;
