@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #include "mail.h"
 
@@ -391,7 +391,7 @@ ml_reread (const char *prompt, char **text)
 
   if (!line)
     {
-      util_error("not enough memory to edit the line");
+      util_error (_("not enough memory to edit the line"));
       return -1;
     }
 
@@ -419,7 +419,7 @@ ml_reread (const char *prompt, char **text)
 	  if ((p = realloc (line, line_size + LINE_INC)) == NULL)
 	    {
 	      fputs ("\n", stdout);
-	      util_error ("not enough memory to edit the line");
+	      util_error (_("not enough memory to edit the line"));
 	      break;
 	    }
 	  else
@@ -465,8 +465,8 @@ ml_reread (const char *prompt, char **text)
 	    {
 	      if ((p = realloc (line, line_size + LINE_INC)) == NULL)
 		{
-		  fputs("\n", stdout);
-		  util_error("not enough memory to edit the line");
+		  fputs ("\n", stdout);
+		  util_error (_("not enough memory to edit the line"));
 		  break;
 		}
 	      else
@@ -502,7 +502,7 @@ ml_reread (const char *prompt, char **text)
 	  if ((p = realloc (line, line_size + LINE_INC)) == NULL)
 	    {
 	      fputs ("\n", stdout);
-	      util_error ("not enough memory to edit the line");
+	      util_error (_("not enough memory to edit the line"));
 	      break;
 	    }
 	  else
