@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2001, 2003 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #include "mail.h"
 
@@ -39,14 +39,14 @@ mail_pipe (int argc, char **argv)
   else if (util_getenv (&cmd, "cmd", Mail_env_boolean, 1))
     return 1;
 
-  if (msgset_parse (argc, argv, &list))
+  if (msgset_parse (argc, argv, MSG_NODELETED|MSG_SILENT, &list))
       return 1;
 
   tube = popen (cmd, "w");
 
   for (mp = list; mp; mp = mp->next)
     {
-      if (util_get_message (mbox, mp->msg_part[0], &msg, MSG_NODELETED) == 0)
+      if (util_get_message (mbox, mp->msg_part[0], &msg) == 0)
 	{
 	  message_get_stream (msg, &stream);
 	  off = 0;
