@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #include "mail.h"
 #include <mailutils/mutil.h>
@@ -40,7 +40,6 @@ typedef struct _node {
 } node;
 
 static node *environment = NULL;
-static node *env_cursor = NULL;
 
 /*
  * add a new node to the list
@@ -148,7 +147,7 @@ util_do_command (const char *c, ...)
     }
   else
     {
-      util_error ("Unknown command: %s", argv[0]);
+      util_error (_("Unknown command: %s"), argv[0]);
       status = 1;
     }
 
@@ -156,79 +155,66 @@ util_do_command (const char *c, ...)
   return status;
 }
 
-/*
- * runs a function repeatedly on a msglist
- * func is the function to run
- * argc is the number of arguments inculding the command and msglist
- * argv is the list of strings containing the command and msglist
- * set_cursor means whether the function should set the cursor to
- * the number of the last message processed. If set_cursor = 0, the
- * cursor is not altered.
- */
-
 int
-util_msglist_command (function_t *func, int argc, char **argv, int set_cursor)
+util_foreach_msg (int argc, char **argv, int flags,
+		  msg_handler_t func, void *data)
 {
   msgset_t *list = NULL, *mp;
   int status = 0;
 
-  if (msgset_parse (argc, argv, &list))
+  if (msgset_parse (argc, argv, flags, &list))
       return 1;
 
-  realcursor = cursor;
-
   for (mp = list; mp; mp = mp->next)
     {
-      cursor = mp->msg_part[0];
-      /* NOTE: Should we bail on error also?  */
-      if (func (1, argv) != 0)
-	status = 1;
-      /* Bail out if we receive an interrupt.  */
-      if (ml_got_interrupt () != 0)
-	break;
+      message_t mesg;
+
+      if (util_get_message (mbox, mp->msg_part[0], &mesg) == 0)
+	{
+	  if (func (mp, mesg, data) != 0)
+	    status = 1;
+	  /* Bail out if we receive an interrupt.  */
+	  if (ml_got_interrupt () != 0)
+	    break;
+	}
     }
   msgset_free (list);
 
-  if (set_cursor)
-    realcursor = cursor;
-  else
-    cursor = realcursor;
   return status;
 }
 
-/* Same as util_msglis_command but the function comes from the escape
-   cmd table, so will have a different argument signature.  */
 int
-util_msglist_esccmd (int (*escfunc)
-		     __P ((int, char **, compose_env_t *)),
-		     int argc, char **argv, compose_env_t *env,
-		     int set_cursor)
+util_range_msg (size_t low, size_t high, int flags, 
+		msg_handler_t func, void *data)
 {
-  msgset_t *list = NULL, *mp;
-  int status = 0;
-
-  if (msgset_parse (argc, argv, &list))
-      return 1;
-
-  realcursor = cursor;
-
-  for (mp = list; mp; mp = mp->next)
+  msgset_t msgspec = { 0 };
+  int count = 0;
+  
+  msgspec.next = NULL;
+  msgspec.npart = 0;
+  msgspec.msg_part = &low;
+  for (; low <= high; low++)
     {
-      cursor = mp->msg_part[0];
-      /* NOTE: Should we bail on error also?  */
-      if (escfunc (1, argv, env) != 0)
-	status = 1;
-      /* Bail out if we receive an interrupt.  */
-      if (ml_got_interrupt () != 0)
-	break;
-    }
-  msgset_free (list);
+     message_t mesg;
 
-  if (set_cursor)
-    realcursor = cursor;
-  else
-    cursor = realcursor;
-  return status;
+     if ((flags & MSG_NODELETED) && util_isdeleted (low))
+       {
+	 if (!(flags & MSG_SILENT))
+	   util_error (_("%lu: Inappropriate message (has been deleted)"),
+		       (unsigned long) low);
+	 continue;
+       }
+     
+     if (util_get_message (mbox, low, &mesg) == 0)
+       {
+	 count ++;
+	 func (&msgspec, mesg, data) ;
+	 /* Bail out if we receive an interrupt.  */
+	 if (ml_got_interrupt () != 0)
+	   break;
+       }
+    }
+  return count;
 }
 
 /*
@@ -390,7 +376,7 @@ util_getenv (void *ptr, const char *variable, mail_env_data_t type, int warn)
   if (!mail_env_entry_is_set (env) || env->type != type)
     {
       if (warn)
-	util_error ("No value set for \"%s\"", variable);
+	util_error (_("No value set for \"%s\""), variable);
       return 1;
     }
   if (ptr)
@@ -420,6 +406,7 @@ util_getenv (void *ptr, const char *variable, mail_env_data_t type, int warn)
 struct mail_env_entry *
 util_find_env (const char *variable, int create)
 {
+  node *ep;
   /* Annoying, variable "ask" is equivalent to "asksub".  */
   static const char *asksub = "asksub";
   const char *var = variable;
@@ -447,20 +434,19 @@ util_find_env (const char *variable, int create)
       environment->next = NULL;
     }
 
-  for (env_cursor = environment; env_cursor->next;
-       env_cursor = env_cursor->next)
+  for (ep = environment; ep->next; ep = ep->next)
     {
-      if (strlen (env_cursor->env_entry.var) == len &&
-	  !strcmp (var, env_cursor->env_entry.var))
-	return &env_cursor->env_entry;
+      if (strlen (ep->env_entry.var) == len &&
+	  !strcmp (var, ep->env_entry.var))
+	return &ep->env_entry;
     }
 
-  env_cursor->env_entry.var = strdup (var);
-  env_cursor->env_entry.set = 0;
-  env_cursor->env_entry.type = Mail_env_whatever;
-  env_cursor->env_entry.value.number = 0;
-  t = env_cursor;
-  env_cursor = util_ll_add (env_cursor, 0);
+  ep->env_entry.var = strdup (var);
+  ep->env_entry.set = 0;
+  ep->env_entry.type = Mail_env_whatever;
+  ep->env_entry.value.number = 0;
+  t = ep;
+  ep = util_ll_add (ep, 0);
   return &t->env_entry;
 }
 
@@ -468,27 +454,27 @@ util_find_env (const char *variable, int create)
 int
 util_printenv (int set)
 {
-  for (env_cursor = environment; env_cursor != NULL;
-       env_cursor = env_cursor->next)
+  node *ep;
+  for (ep = environment; ep != NULL; ep = ep->next)
     {
-      if (env_cursor->env_entry.set == set)
+      if (ep->env_entry.set == set)
 	{
-	  fprintf (ofile, "%s", env_cursor->env_entry.var);
-	  switch (env_cursor->env_entry.type)
+	  fprintf (ofile, "%s", ep->env_entry.var);
+	  switch (ep->env_entry.type)
 	    {
 	    case Mail_env_number:
-	      fprintf (ofile, "=%d", env_cursor->env_entry.value.number);
+	      fprintf (ofile, "=%d", ep->env_entry.value.number);
 	      break;
 	      
 	    case Mail_env_string:
-	      fprintf (ofile, "=\"%s\"", env_cursor->env_entry.value.string);
+	      fprintf (ofile, "=\"%s\"", ep->env_entry.value.string);
 	      break;
 	      
 	    case Mail_env_boolean:
 	      break;
 	      
 	    case Mail_env_whatever:
-	      fprintf (ofile, "oops?");
+	      fprintf (ofile, _("oops?"));
 	    }
 	  fprintf (ofile, "\n");
 	}
@@ -567,11 +553,14 @@ util_setenv (const char *variable, void *value, mail_env_data_t type,
 /*
  * return 1 if a message is deleted
  */
-int
-util_isdeleted (message_t msg)
-{
-  attribute_t attr;
 
+int
+util_isdeleted (size_t n)
+{
+  message_t msg = NULL;
+  attribute_t attr = NULL;
+
+  mailbox_get_message (mbox, n, &msg);
   message_get_attribute (msg, &attr);
   return attribute_is_deleted (attr);
 }
@@ -583,7 +572,7 @@ util_get_homedir ()
   if (!homedir)
     {
       /* Shouldn't happen, but one never knows */
-      util_error ("can't get homedir");
+      util_error (_("can't get homedir"));
       exit (EXIT_FAILURE);
     }
   return homedir;
@@ -646,14 +635,14 @@ util_get_sender(int msgno, int strip)
       if (envelope_sender (env, buffer, sizeof (buffer), NULL)
 	  || address_create (&addr, buffer))
 	{
-	  util_error("can't determine sender name (msg %d)", msgno);
+	  util_error (_("can't determine sender name (msg %d)"), msgno);
 	  return NULL;
 	}
     }
 
   if (address_get_email (addr, 1, buffer, sizeof(buffer), NULL))
     {
-      util_error("can't determine sender name (msg %d)", msgno);
+      util_error (_("can't determine sender name (msg %d)"), msgno);
       address_destroy (&addr);
       return NULL;
     }
@@ -721,7 +710,7 @@ util_slist_add (list_t *list, char *value)
 
   if ((p = strdup(value)) == NULL)
     {
-      util_error("not enough memory\n");
+      util_error(_("not enough memory\n"));
       return;
     }
   list_append (*list, p);
@@ -879,7 +868,7 @@ util_save_outgoing (message_t msg, char *savefile)
       outfile = fopen (filename, "a");
       if (!outfile)
 	{
-	  util_error("can't open save file %s: %s",
+	  util_error(_("can't open save file %s: %s"),
 		     filename, strerror (errno));
 	}
       else
@@ -896,7 +885,7 @@ util_save_outgoing (message_t msg, char *savefile)
 
 	  if (!bsize)
 	    {
-	      util_error("not enough memory for creating save file");
+	      util_error(_("not enough memory for creating save file"));
 	    }
 	  else
 	    {
@@ -981,7 +970,7 @@ util_help (const struct mail_command_entry *table, char *word)
       else
 	{
 	  status = 1;
-	  fprintf (stdout, "Unknown command: %s\n", word);
+	  fprintf (stdout, _("Unknown command: %s\n"), word);
 	}
       return status;
     }
@@ -1006,7 +995,7 @@ util_descend_subparts (message_t mesg, msgset_t *msgset, message_t *part)
 	{
 	  if (message_unencapsulate (mesg, &submsg, NULL))
 	    {
-	      util_error ("can't unencapsulate message/part");
+	      util_error (_("can't unencapsulate message/part"));
 	      return 1;
 	    }
 	  mesg = submsg;
@@ -1015,14 +1004,14 @@ util_descend_subparts (message_t mesg, msgset_t *msgset, message_t *part)
       message_get_num_parts (mesg, &nparts);
       if (nparts < msgset->msg_part[i])
 	{
-	  util_error ("no such (sub)part in the message: %d",
+	  util_error (_("no such (sub)part in the message: %d"),
 		      msgset->msg_part[i]);
 	  return 1;
 	}
 
       if (message_get_part (mesg, msgset->msg_part[i], &submsg))
 	{
-	  util_error ("can't get (sub)part from the message: %d",
+	  util_error (_("can't get (sub)part from the message: %d"),
 		      msgset->msg_part[i]);
 	  return 1;
 	}
@@ -1146,7 +1135,7 @@ util_header_expand (header_t *phdr)
   rc = header_create (&hdr, "", 0, NULL);
   if (rc)
     {
-      util_error ("can't create temporary header: %s", mu_errstring (rc));
+      util_error (_("can't create temporary header: %s"), mu_strerror (rc));
       return 1;
     }
       
@@ -1187,11 +1176,11 @@ util_header_expand (header_t *phdr)
 		{
 		  errcnt++;
 		  if (exp)
-		    util_error ("can't parse address `%s' (while expanding `%s'): %s",
-				exp, p, mu_errstring (rc));
+		    util_error (_("can't parse address `%s' (while expanding `%s'): %s"),
+				exp, p, mu_strerror (rc));
 		  else
-		    util_error ("can't parse address `%s': %s",
-				p, mu_errstring (rc));
+		    util_error (_("can't parse address `%s': %s"),
+				p, mu_strerror (rc));
 		}
 	      
 	      free (exp);
@@ -1230,7 +1219,7 @@ util_header_expand (header_t *phdr)
 }
 
 int
-util_get_message (mailbox_t mbox, size_t msgno, message_t *msg, int flag)
+util_get_message (mailbox_t mbox, size_t msgno, message_t *msg)
 {
   int status;
 
@@ -1243,24 +1232,23 @@ util_get_message (mailbox_t mbox, size_t msgno, message_t *msg, int flag)
   status = mailbox_get_message (mbox, msgno, msg);
   if (status)
     {
-      util_error ("can't get message %lu: %s",
-		  (unsigned long) msgno, mu_errstring (status));
+      util_error (_("can't get message %lu: %s"),
+		  (unsigned long) msgno, mu_strerror (status));
       return status;
     }
 
-  if ((flag & MSG_NODELETED) && util_isdeleted (*msg))
-    {
-      if (!(flag & MSG_SILENT))
-	util_error ("%lu: Inappropriate message (has been deleted)",
-		    (unsigned long) msgno);
-      return ENOENT;
-    }
   return 0;
 }
 
 int
 util_error_range (size_t msgno)
 {
-  util_error ("%d: invalid message number", msgno);
+  util_error (_("%d: invalid message number"), msgno);
   return 1;
 }
+
+void
+util_noapp ()
+{
+  util_error (_("No applicable messages"));
+}
