@@ -1,19 +1,20 @@
-/* GNU mailutils - a suite of utilities for electronic mail
+/* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Library Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   This library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Lesser General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
 
-   This program is distributed in the hope that it will be useful,
+   This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU Library General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Lesser General Public License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with this library; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
-   You should have received a copy of the GNU Library General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
 /* Credits.  Some of the Readline an buffering scheme was taken
    from 4.4BSDLite2.
@@ -109,6 +110,9 @@ stream_close (stream_t stream)
 {
   if (stream == NULL)
     return EINVAL;
+  if (stream->state == MU_STREAM_STATE_CLOSE)
+    return 0;
+  
   stream->state = MU_STREAM_STATE_CLOSE;
   /* Clear the buffer of any residue left.  */
   if (stream->rbuffer.base)
@@ -641,6 +645,112 @@ stream_set_flags (stream_t stream, int fl)
   return 0;
 }
 
+int
+stream_set_strerror (stream_t stream,
+		     int (*fp) (stream_t, char **), void *owner)
+{
+  if (stream == NULL)
+    return EINVAL;
+  if (stream->owner != owner)
+    return EACCES;
+  stream->_strerror = fp;
+  return 0;
+}
+
+int
+stream_sequential_read (stream_t stream, char *buf, size_t size,
+			size_t *nbytes)
+{
+  size_t rdbytes;
+  int rc = stream_read (stream, buf, size, stream->offset, &rdbytes);
+  if (!rc)
+    {
+      stream->offset += rdbytes;
+      if (nbytes)
+	*nbytes = rdbytes;
+    }
+  return rc;
+}
+
+int
+stream_sequential_readline (stream_t stream, char *buf, size_t size,
+			    size_t *nbytes)
+{
+  size_t rdbytes;
+  int rc = stream_readline (stream, buf, size, stream->offset, &rdbytes);
+  if (!rc)
+    {
+      stream->offset += rdbytes;
+      if (nbytes)
+	*nbytes = rdbytes;
+    }
+  return rc;
+}
+
+int
+stream_sequential_write (stream_t stream, char *buf, size_t size)
+{
+  if (stream == NULL)
+    return EINVAL;
+  while (size > 0)
+    {
+      size_t sz;
+      int rc = stream_write (stream, buf, size, stream->offset, &sz);
+      if (rc)
+	return rc;
+
+      buf += sz;
+      size -= sz;
+      stream->offset += sz;
+    }
+  return 0;
+}
+
+int
+stream_seek (stream_t stream, off_t off, int whence)
+{
+  off_t size = 0;
+  size_t pos;
+  int rc;
+  
+  if ((rc = stream_size (stream, &size)))
+    return rc;
+  
+  switch (whence)
+    {
+    case SEEK_SET:
+      pos = off;
+      break;
+      
+    case SEEK_CUR:
+      pos = off + stream->offset;
+      break;
+      
+    case SEEK_END:
+      pos = size + off;
+      break;
+      
+    default:
+      return EINVAL;
+    }
+
+  if (pos > size)
+    return EIO;
+  
+  stream->offset = pos;
+  return 0;
+}
+
+int
+stream_strerror (stream_t stream, char **p)
+{
+  if (stream == NULL)
+    return EINVAL;
+  if (stream->_strerror)
+    return stream->_strerror (stream, p);
+  return ENOSYS;
+}
+
 static int
 refill (stream_t stream, off_t offset)
 {
