@@ -1,42 +1,46 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 /* fmtcheck */
 
 #include <mh.h>
 
 const char *argp_program_version = "fmtcheck (" PACKAGE_STRING ")";
-static char doc[] = "GNU MH fmtcheck";
+static char doc[] = N_("GNU MH fmtcheck\v"
+"Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = "";
 
 /* GNU options */
 static struct argp_option options[] = {
-  {"form",    'F', "FILE",   0, "Read format from given file"},
-  {"format",  't', "FORMAT", 0, "Use this format string"},
-  {"dump",    'd', NULL,     0, "Dump the listing of compiled format code"},
-  { "\nUse -help switch to obtain the list of traditional MH options. ", 0, 0, OPTION_DOC, "" },
-  
+  {"form",    ARG_FORM, N_("FILE"),   0,
+   N_("Read format from given file")},
+  {"format",  ARG_FORMAT, N_("FORMAT"), 0,
+   N_("Use this format string")},
+  {"dump",    ARG_DUMP, NULL,     0,
+   N_("Dump the listing of compiled format code")},
+  { "debug",  ARG_DEBUG, NULL,     0,
+    N_("Enable parser debugging output"),},
   { 0 }
 };
 
 /* Traditional MH options */
 struct mh_option mh_option[] = {
-  {"form",    4,  'F', MH_OPT_ARG, "formatfile"},
-  {"format",  5,  't', MH_OPT_ARG, "string"},
+  {"form",    4,  MH_OPT_ARG, "formatfile"},
+  {"format",  5,  MH_OPT_ARG, "string"},
   { 0 }
 };
 
@@ -50,7 +54,7 @@ action_dump ()
 {
   if (!format_str)
     {
-      mh_error ("format string not specified");
+      mh_error (_("format string not specified"));
       return 1;
     }
   mh_format_dump (&format);
@@ -60,21 +64,25 @@ action_dump ()
 static action_fp action = action_dump;
 
 static int
-opt_handler (int key, char *arg, void *unused)
+opt_handler (int key, char *arg, void *unused, struct argp_state *state)
 {
   switch (key)
     {
-    case 'F':
+    case ARG_FORM:
       mh_read_formfile (arg, &format_str);
       break;
 
-    case 't':
+    case ARG_FORMAT:
       format_str = arg;
       break;
 
-    case 'd':
+    case ARG_DUMP:
       action = action_dump;
       break;
+
+    case ARG_DEBUG:
+      mh_format_debug (1);
+      break;
       
     default:
       return 1;
@@ -85,12 +93,15 @@ opt_handler (int key, char *arg, void *unused)
 int
 main (int argc, char **argv)
 {
-  mh_argp_parse (argc, argv, options, mh_option, args_doc, doc,
+  /* Native Language Support */
+  mu_init_nls ();
+
+  mh_argp_parse (argc, argv, 0, options, mh_option, args_doc, doc,
 		 opt_handler, NULL, NULL);
 
   if (format_str && mh_format_parse (format_str, &format))
     {
-      mh_error ("Bad format string");
+      mh_error (_("Bad format string"));
       exit (1);
     }
   return (*action) ();
