@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -40,8 +40,18 @@
 #include <mailutils/attribute.h>
 #include <mailutils/error.h>
 #include <mailutils/errno.h>
+#include <mailutils/nls.h>
+#include <mailutils/argcv.h>
+#include <mailutils/debug.h>
+#include <mailutils/mailer.h>
+#include <mailutils/envelope.h>
 
 #include <mu_asprintf.h>
+#include <getline.h>
+
+#if !HAVE_DECL_STRCHRNUL
+extern char *strchrnul __P((const char *s, int c_in));
+#endif
 
 #define MH_FMT_RALIGN 0x1000
 #define MH_FMT_ZEROPAD 0x2000
@@ -175,14 +185,47 @@ typedef struct
 typedef void (*mh_iterator_fp) __P((mailbox_t mbox, message_t msg,
 				    size_t num, void *data));
 
+/* Recipient masks */
+#define RCPT_NONE 0
+#define RCPT_TO   0x0001
+#define RCPT_CC   0x0002
+#define RCPT_ME   0x0004
+#define RCPT_ALL  (RCPT_TO|RCPT_CC|RCPT_ME)
+
+#define RCPT_DEFAULT RCPT_NONE
+
+struct mh_whatnow_env {   /* An environment for whatnow shell */
+  char *file;             /* The file being processed */
+  char *msg;              /* The original message (if any) */
+  char *draftfile;        /* File to preserve the draft into */
+  char *draftfolder;
+  char *draftmessage;
+  char *editor;
+  char *prompt;
+};
+
+#define DISP_QUIT 0
+#define DISP_USE 1
+#define DISP_REPLACE 2
+
+typedef int (*mh_context_iterator) __PMT((char *field,
+					  char *value, char *data));
+
+#define SEQ_PRIVATE 1
+#define SEQ_ZERO    2
+
 extern char *current_folder;
 extern size_t current_message;
 extern char mh_list_format[];
+extern int rcpt_mask;
 
 void mh_init __P((void));
 void mh_init2 __P((void));
 void mh_read_profile __P((void));
 int mh_read_formfile __P((char *name, char **pformat));
+message_t mh_file_to_message (char *folder, char *file_name);
+message_t mh_stream_to_message (stream_t stream);
+void mh_install __P((char *name, int automode));
 
 char *mh_global_profile_get __P((char *name, char *defval));
 int mh_global_profile_set __P((const char *name, const char *value));
@@ -192,18 +235,22 @@ char *mh_current_folder __P((void));
 char *mh_global_sequences_get __P((const char *name, const char *defval));
 int mh_global_sequences_set __P((const char *name, const char *value));
 void mh_global_save_state __P((void));
+int mh_global_context_iterate __P((mh_context_iterator fp, void *data));
+int mh_global_sequences_iterate __P((mh_context_iterator fp, void *data));
 
 int mh_getyn __P((const char *fmt, ...));
 int mh_check_folder __P((char *pathname, int confirm));
 
 int mh_format __P((mh_format_t *fmt, message_t msg, size_t msgno,
-		   char *buffer, size_t bufsize));
+		   size_t width, char **pret));
 void mh_format_dump __P((mh_format_t *fmt));
 int mh_format_parse __P((char *format_str, mh_format_t *fmt));
+void mh_format_debug __P((int val));
 void mh_format_free __P((mh_format_t *fmt));
 mh_builtin_t *mh_lookup_builtin __P((char *name, int *rest));
 
 void mh_error __P((const char *fmt, ...));
+void mh_err_memory __P((int fatal));
 
 FILE *mh_audit_open __P((char *name, mailbox_t mbox));
 void mh_audit_close __P((FILE *fp));
@@ -215,6 +262,8 @@ char *mh_context_get_value __P((mh_context_t *ctx, const char *name,
 				const char *defval));
 int mh_context_set_value __P((mh_context_t *ctx, const char *name,
 			      const char *value));
+int mh_context_iterate __P((mh_context_t *ctx,
+			    mh_context_iterator fp, void *data));
 
 int mh_message_number __P((message_t msg, size_t *pnum));
 
@@ -229,7 +278,7 @@ int mh_msgset_current __P((mailbox_t mbox, mh_msgset_t *msgset, int index));
 void mh_msgset_free __P((mh_msgset_t *msgset));
 
 char *mh_get_dir __P((void));
-char *mh_expand_name __P((const char *name, int is_folder));
+char *mh_expand_name __P((const char *base, const char *name, int is_folder));
 
 int mh_is_my_name __P((char *name));
 char * mh_my_email __P((void));
@@ -237,8 +286,27 @@ char * mh_my_email __P((void));
 int mh_iterate __P((mailbox_t mbox, mh_msgset_t *msgset,
 		    mh_iterator_fp itr, void *data));
 
-size_t mh_get_message (mailbox_t mbox, size_t seqno, message_t *mesg);
+size_t mh_get_message __P((mailbox_t mbox, size_t seqno, message_t *mesg));
+
+int mh_decode_rcpt_flag __P((const char *arg));
 
 void *xmalloc __P((size_t));
 void *xrealloc __P((void *, size_t));
      
+int mh_spawnp __P((const char *prog, const char *file));
+int mh_whatnow __P((struct mh_whatnow_env *wh, int initial_edit));
+int mh_disposition __P((const char *filename));
+int mh_usedraft __P((const char *filename));
+int mh_file_copy __P((const char *from, const char *to));
+
+void mh_annotate __P((message_t msg, char *field, char *text, int date));
+
+list_t mhl_format_compile __P((char *name));
+int mhl_format_run __P((list_t fmt, int width, int length,
+			int clearscreen, int bell,
+			message_t msg, stream_t output));
+void mhl_format_destroy (list_t *fmt);
+
+void mh_seq_add __P((char *name, mh_msgset_t *mset, int flags));
+int mh_seq_delete __P((char *name, mh_msgset_t *mset, int flags));
+char *mh_seq_read __P((char *name, int flags));
