@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
+/* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 2002 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 /* MH rmf command */
 
@@ -29,21 +29,24 @@
 #include <dirent.h>
 
 const char *argp_program_version = "rmf (" PACKAGE_STRING ")";
-static char doc[] = "GNU MH rmf";
-static char args_doc[] = "[+folder]";
+static char doc[] = N_("GNU MH rmf\v"
+"Use -help to obtain the list of traditional MH options.");
+static char args_doc[] = N_("[+folder]");
 
 /* GNU options */
 static struct argp_option options[] = {
-  {"folder",  'f', "FOLDER", 0, "Specify the folder to delete"},
-  {"interactive", 'i', "BOOL", OPTION_ARG_OPTIONAL, "Interactive mode: ask for confirmation before removing each folder"},
-  {"recursive", 'r', NULL, 0, "Recursively delete all subfolders"},
-  { "\nUse -help switch to obtain the list of traditional MH options. ", 0, 0, OPTION_DOC, "" },
+  {"folder",  ARG_FOLDER, N_("FOLDER"), 0,
+   N_("Specify the folder to delete")},
+  {"interactive", ARG_INTERACTIVE, N_("BOOL"), OPTION_ARG_OPTIONAL,
+    N_("Interactive mode: ask for confirmation before removing each folder")},
+  {"recursive", ARG_RECURSIVE, NULL, 0,
+   N_("Recursively delete all subfolders")},
   { 0 }
 };
 
 /* Traditional MH options */
 struct mh_option mh_option[] = {
-  {"interactive", 1, 'i', MH_OPT_BOOL, NULL},
+  {"interactive", 1, MH_OPT_BOOL, NULL},
   { 0 }
 };
 
@@ -52,21 +55,21 @@ int interactive; /* Ask for confirmation before deleting */
 int recurse;     /* Recursively process all the sub-directories */
 
 static int
-opt_handler (int key, char *arg, void *unused)
+opt_handler (int key, char *arg, void *unused, struct argp_state *state)
 {
   switch (key)
     {
     case '+':
-    case 'f':
+    case ARG_FOLDER:
       explicit_folder = 1;
       current_folder = arg;
       break;
 
-    case 'i':
+    case ARG_INTERACTIVE:
       interactive = is_true (arg);
       break;
 
-    case 'r':
+    case ARG_RECURSIVE:
       recurse = is_true (arg);
       break;
       
@@ -86,11 +89,11 @@ rmf (const char *name)
 
   if (!dir)
     {
-      mh_error ("can't scan folder %s: %s", name, strerror (errno));
+      mh_error (_("can't scan folder %s: %s"), name, strerror (errno));
       return;
     }
 
-  if (interactive && !mh_getyn ("Remove folder %s", name))
+  if (interactive && !mh_getyn (_("Remove folder %s"), name))
     exit (0);
   
   while ((entry = readdir (dir)))
@@ -105,7 +108,7 @@ rmf (const char *name)
       asprintf (&p, "%s/%s", name, entry->d_name);
       if (stat (p, &st) < 0)
 	{
-	  mh_error ("can't stat %s: %s", p, strerror (errno));
+	  mh_error (_("can't stat %s: %s"), p, strerror (errno));
 	}
       else if (S_ISDIR (st.st_mode))
 	{
@@ -115,7 +118,7 @@ rmf (const char *name)
       else
 	{
 	  if (unlink (p))
-	    mh_error ("can't unlink %s: %s", p, strerror (errno));
+	    mh_error (_("can't unlink %s: %s"), p, strerror (errno));
 	}
       free (p);
     }
@@ -127,12 +130,16 @@ int
 main (int argc, char **argv)
 {
   char *name;
-  mh_argp_parse (argc, argv, options, mh_option, args_doc, doc,
+
+  /* Native Language Support */
+  mu_init_nls ();
+
+  mh_argp_parse (argc, argv, 0, options, mh_option, args_doc, doc,
 		 opt_handler, NULL, NULL);
   if (!explicit_folder)
     interactive = 1;
 
-  name = mh_expand_name (current_folder, 0);
+  name = mh_expand_name (NULL, current_folder, 0);
   rmf (name);
   return 0;
 }
