@@ -1,19 +1,19 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #include "pop3d.h"
 
@@ -53,10 +53,10 @@ pop3d_apopuser (const char *user)
     if (rc)
       {
 	if (rc == -1)
-	  syslog (LOG_INFO, "Bad permissions on APOP password db");
+	  syslog (LOG_INFO, _("Bad permissions on APOP password db"));
 	else
-	  syslog (LOG_ERR, "Unable to open APOP db: %s",
-		  mu_errstring (rc));
+	  syslog (LOG_ERR, _("Unable to open APOP db: %s"),
+		  mu_strerror (rc));
 	return NULL;
       }
 
@@ -73,7 +73,7 @@ pop3d_apopuser (const char *user)
     mu_dbm_close (db);
     if (rc)
       {
-	syslog (LOG_ERR, "Can't fetch APOP data: %s", mu_errstring (rc));
+	syslog (LOG_ERR, _("Can't fetch APOP data: %s"), mu_strerror (rc));
 	return NULL;
       }
     password = calloc (MU_DATUM_SIZE(data) + 1, sizeof (*password));
@@ -91,14 +91,14 @@ pop3d_apopuser (const char *user)
 
     if (mu_check_perm (APOP_PASSFILE, 0600))
       {
-	syslog (LOG_INFO, "Bad permissions on APOP password file");
+	syslog (LOG_INFO, _("Bad permissions on APOP password file"));
 	return NULL;
     }
 
     apop_file = fopen (APOP_PASSFILE, "r");
     if (apop_file == NULL)
       {
-	syslog (LOG_INFO, "Unable to open APOP password file %s",
+	syslog (LOG_INFO, _("Unable to open APOP password file %s"),
 		strerror (errno));
 	return NULL;
       }
@@ -255,7 +255,7 @@ pop3d_apop (const char *arg)
   {
     url_t url = NULL;
     mailbox_get_url (mbox, &url);
-    syslog (LOG_INFO, "User '%s' logged in with mailbox '%s'",
+    syslog (LOG_INFO, _("User '%s' logged in with mailbox '%s'"),
             username, url_to_string (url));
   }
   return OK;
