@@ -1,27 +1,25 @@
-/* GNU mailutils - a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+/* GNU Mailutils -- a suite of utilities for electronic mail
+   Copyright (C) 1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2, or (at your option)
    any later version.
 
-   This program is distributed in the hope that it will be useful,
+   GNU Mailutils is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with GNU Mailutils; if not, write to the Free Software
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
 
 #include "pop3d.h"
 
 mailbox_t mbox;
 int state;
 char *username;
-FILE *ifile;
-FILE *ofile;
 char *md5shared;
 
 struct daemon_param daemon_param = {
@@ -34,17 +32,23 @@ struct daemon_param daemon_param = {
 
 int debug_mode;
 
+#ifdef WITH_TLS
+int tls_available;
+int tls_done;
+#endif /* WITH_TLS */
+
 /* Number of child processes.  */
 volatile size_t children;
 
-static int pop3d_mainloop       __P ((int, int));
+static int pop3d_mainloop       __P ((int fd, FILE *, FILE *));
 static void pop3d_daemon_init   __P ((void));
 static void pop3d_daemon        __P ((unsigned int, unsigned int));
 static error_t pop3d_parse_opt  __P((int key, char *arg,
 				     struct argp_state *astate));
+static void pop3d_log_connection __P((int fd));
 
 const char *argp_program_version = "pop3d (" PACKAGE_STRING ")";
-static char doc[] = "GNU pop3d -- the POP3 daemon";
+static char doc[] = N_("GNU pop3d -- the POP3 daemon");
 
 static struct argp argp = {
   NULL,
@@ -58,6 +62,9 @@ static struct argp argp = {
 static const char *pop3d_argp_capa[] = {
   "daemon",
   "auth",
+#ifdef WITH_TLS
+  "tls",
+#endif /* WITH_TLS */
   "common",
   "mailbox",
   "logging",
@@ -87,7 +94,13 @@ main (int argc, char **argv)
   struct group *gr;
   int status = OK;
 
+  /* Native Language Support */
+  mu_init_nls ();
+
   MU_AUTH_REGISTER_ALL_MODULES();
+#ifdef WITH_TLS
+  mu_tls_init_argp ();
+#endif /* WITH_TLS */
   mu_argp_parse (&argp, &argc, &argv, 0, pop3d_argp_capa, NULL, &daemon_param);
 
 #ifdef USE_LIBPAM
@@ -105,17 +118,17 @@ main (int argc, char **argv)
       gr = getgrnam ("mail");
       if (gr == NULL)
 	{
-	  perror ("Error getting mail group");
+	  perror (_("Error getting mail group"));
 	  exit (EXIT_FAILURE);
 	}
 
       if (setgid (gr->gr_gid) == -1)
 	{
-	  perror ("Error setting mail group");
+	  perror (_("Error setting mail group"));
 	  exit (EXIT_FAILURE);
 	}
     }
-  
+
   /* Register the desired formats.  */
   {
     list_t bookie;
@@ -152,12 +165,19 @@ main (int argc, char **argv)
   
   umask (S_IROTH | S_IWOTH | S_IXOTH);	/* 007 */
 
+  /* Check TLS environment, i.e. cert and key files */
+#ifdef WITH_TLS
+  tls_available = mu_check_tls_environment ();
+  if (tls_available)
+    tls_available = mu_init_tls_libs ();
+#endif /* WITH_TLS */
+
   /* Actually run the daemon.  */
   if (daemon_param.mode == MODE_DAEMON)
     pop3d_daemon (daemon_param.maxchildren, daemon_param.port);
   /* exit (EXIT_SUCCESS) -- no way out of daemon except a signal.  */
   else
-    status = pop3d_mainloop (fileno (stdin), fileno (stdout));
+    status = pop3d_mainloop (fileno (stdin), stdin, stdout);
 
   /* Close the syslog connection and exit.  */
   closelog ();
@@ -174,7 +194,7 @@ pop3d_daemon_init (void)
      first three one, in, out, err   */
   if (daemon (0, 0) < 0)
     {
-      perror ("failed to become a daemon:");
+      perror (_("failed to become a daemon:"));
       exit (EXIT_FAILURE);
     }
 
@@ -192,42 +212,50 @@ pop3d_daemon_init (void)
 #endif
 }
 
+void
+pop3d_log_connection (int fd)
+{
+  syslog (LOG_INFO, _("Incoming connection opened"));
+
+  /* log information on the connecting client */
+  if (debug_mode)
+    {
+      syslog (LOG_INFO, _("Started in debugging mode"));
+    }
+  else
+    {
+      struct sockaddr_in cs;
+      int len = sizeof cs;
+      if (getpeername (fd, (struct sockaddr*)&cs, &len) < 0)
+	syslog (LOG_ERR, _("can't obtain IP address of client: %s"),
+		strerror (errno));
+      else
+	syslog (LOG_INFO, _("connect from %s"), inet_ntoa (cs.sin_addr));
+    }
+}
+
 /* The main part of the daemon. This function reads input from the client and
-   executes the proper functions. Also handles the bulk of error reporting.  */
+   executes the proper functions. Also handles the bulk of error reporting.
+   Arguments:
+      fd        --  socket descriptor (for diagnostics)
+      infile    --  input stream
+      outfile   --  output stream */
 static int
-pop3d_mainloop (int infile, int outfile)
+pop3d_mainloop (int fd, FILE *infile, FILE *outfile)
 {
   int status = OK;
+  char buffer[512];
 
   /* Reset hup to exit.  */
   signal (SIGHUP, pop3d_signal);
   /* Timeout alarm.  */
   signal (SIGALRM, pop3d_signal);
 
-  ifile = fdopen (infile, "r");
-  ofile = fdopen (outfile, "w");
-  if (!ifile || !ofile)
-    pop3d_abquit (ERR_NO_OFILE);
+  pop3d_setio (infile, outfile);
 
   state = AUTHORIZATION;
 
-  syslog (LOG_INFO, "Incoming connection opened");
-
-  /* log information on the connecting client */
-  if (debug_mode)
-    {
-      syslog (LOG_INFO, "Started in debugging mode");
-    }
-  else
-    {
-      struct sockaddr_in cs;
-      int len = sizeof cs;
-      if (getpeername (infile, (struct sockaddr*)&cs, &len) < 0)
-	syslog (LOG_ERR, "can't obtain IP address of client: %s",
-		strerror (errno));
-      else
-	syslog (LOG_INFO, "connect from %s", inet_ntoa(cs.sin_addr));
-    }
+  pop3d_log_connection (fd);
 
   /* Prepare the shared secret for APOP.  */
   {
@@ -264,9 +292,9 @@ pop3d_mainloop (int infile, int outfile)
     {
       char *buf, *arg, *cmd;
 
-      fflush (ofile);
+      pop3d_flush_output ();
       status = OK;
-      buf = pop3d_readline (ifile);
+      buf = pop3d_readline (buffer, sizeof (buffer));
       cmd = pop3d_cmd (buf);
       arg = pop3d_args (buf);
 
@@ -320,6 +348,10 @@ pop3d_mainloop (int infile, int outfile)
 	status = pop3d_uidl (arg);
       else if (strncasecmp (cmd, "CAPA", 4) == 0)
 	status = pop3d_capa (arg);
+#ifdef WITH_TLS
+      else if ((strncasecmp (cmd, "STLS", 4) == 0) && tls_available)
+	status = pop3d_stls (arg);
+#endif /* WITH_TLS */
       else
 	status = ERR_BAD_CMD;
 
@@ -345,6 +377,10 @@ pop3d_mainloop (int infile, int outfile)
 	pop3d_outf ("-ERR " TOO_LONG "\r\n");
       else if (status == ERR_FILE)
 	pop3d_outf ("-ERR " FILE_EXP "\r\n");
+#ifdef WITH_TLS
+      else if (status == ERR_TLS_ACTIVE)
+	pop3d_outf ("-ERR " TLS_ACTIVE "\r\n");
+#endif /* WITH_TLS */
       else
 	pop3d_outf ("-ERR unknown error\r\n");
 
@@ -352,6 +388,8 @@ pop3d_mainloop (int infile, int outfile)
       free (arg);
     }
 
+  pop3d_bye ();
+
   return (status != OK);
 }
 
@@ -397,7 +435,7 @@ pop3d_daemon (unsigned int maxchildren, unsigned int port)
     {
       if (children > maxchildren)
         {
-	  syslog (LOG_ERR, "too many children (%lu)",
+	  syslog (LOG_ERR, _("too many children (%lu)"),
 		  (unsigned long) children);
           pause ();
           continue;
@@ -419,8 +457,10 @@ pop3d_daemon (unsigned int maxchildren, unsigned int port)
       else if (pid == 0) /* Child.  */
         {
 	  int status;
-          close (listenfd);
-          status = pop3d_mainloop (connfd, connfd);
+	  
+	  close (listenfd);
+          status = pop3d_mainloop (connfd,
+				   fdopen (connfd, "r"), fdopen (connfd, "w"));
 	  closelog ();
 	  exit (status);
         }
@@ -432,6 +472,3 @@ pop3d_daemon (unsigned int maxchildren, unsigned int port)
     }
 }
 
-
-
-
